@@ -52,10 +52,17 @@ mod_qui_quadrado_server <- function(id, tipo = "tamanho_amostral", txt_ajuda, tx
 
           sidebarLayout(
             sidebarPanel(
+
+              wellPanel(HTML(
+                '<b><a href="https://youtu.be/ldNW1ctO3uE" target="_blank">',
+                translation_pss("Vídeo: PSS Health para comparação de três proporções independentes", linguagem()),
+                '</a></b><br>'
+              )),
+
               textInput(inputId = ns("chisq_desfecho"),
                         label   = translation_pss("Descreva o nome das variáveis que deseja associar", linguagem()),
                         value   = translation_pss("X1 e X2", linguagem())
-              ) %>% .help_buttom(body = txt_outros_desfechos()),
+              ) %>% .help_buttom(linguagem = linguagem(), body = txt_outros_desfechos()),
 
 
               selectInput(inputId = ns("chisq_input"),
@@ -74,7 +81,7 @@ mod_qui_quadrado_server <- function(id, tipo = "tamanho_amostral", txt_ajuda, tx
                             min = 0,
                             max = 100,
                             step = 1
-              ) %>% .help_buttom(body = txt_ajuda()$txt_significancia, title = translation_pss("Nível de significância (%)", linguagem())),
+              ) %>% .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_significancia, title = translation_pss("Nível de significância (%)", linguagem())),
 
               if (tipo == "tamanho_amostral") {
                 numericInput( ns("chisq_perdas_recusa"),
@@ -83,7 +90,7 @@ mod_qui_quadrado_server <- function(id, tipo = "tamanho_amostral", txt_ajuda, tx
                               min = 0,
                               max = 100,
                               step = 1
-                ) %>% .help_buttom(body = txt_ajuda()$txt_perdas_recusas, title = translation_pss("Perdas/ Recusas (%)", linguagem()))
+                ) %>% .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_perdas_recusas, title = translation_pss("Perdas/ Recusas (%)", linguagem()))
               }
             ),
 
@@ -111,7 +118,7 @@ mod_qui_quadrado_server <- function(id, tipo = "tamanho_amostral", txt_ajuda, tx
                         min = 0,
                         max = 100,
                         step = 1
-          ) %>% .help_buttom(body = txt_ajuda()$txt_power, title = translation_pss("Poder (%)", linguagem()))
+          ) %>% .help_buttom(linguagem = linguagem(), body = txt_ajuda()$txt_power, title = translation_pss("Poder (%)", linguagem()))
         } else if (input$chisq_input != 3) {
           numericInput( ns("chisq_n"),
                         translation_pss("Tamanho amostral", linguagem()),
@@ -136,7 +143,7 @@ mod_qui_quadrado_server <- function(id, tipo = "tamanho_amostral", txt_ajuda, tx
                           min = 0,
                           max = 1,
                           step = .01
-            ) %>% .help_buttom(body = paste0(translation_pss("Tamanho de efeito w de Cohen", linguagem()), txt_ajuda()$txt_definido_pesquisador_OU_literatura)),
+            ) %>% .help_buttom(linguagem = linguagem(), body = paste0(translation_pss("Tamanho de efeito w de Cohen", linguagem()), txt_ajuda()$txt_definido_pesquisador_OU_literatura)),
 
 
             numericInput( ns("df_chisq_n"),
@@ -145,7 +152,7 @@ mod_qui_quadrado_server <- function(id, tipo = "tamanho_amostral", txt_ajuda, tx
                           min = 0,
                           max = Inf,
                           step = 1
-            ) %>% .help_buttom(body = paste0("Número de graus de liberdade da estatística de teste. Pode ser obtido realizando o cálculo (L-1)x(C-1), onde L é o número de categorias da primeira variável e C da segunda variável.", txt_ajuda()$txt_definido_pesquisador_OU_literatura))
+            ) %>% .help_buttom(linguagem = linguagem(), body = paste0("Número de graus de liberdade da estatística de teste. Pode ser obtido realizando o cálculo (L-1)x(C-1), onde L é o número de categorias da primeira variável e C da segunda variável.", txt_ajuda()$txt_definido_pesquisador_OU_literatura))
           ))
         } else {
 
@@ -302,7 +309,7 @@ mod_qui_quadrado_server <- function(id, tipo = "tamanho_amostral", txt_ajuda, tx
           list(w = input$w_chisq_n, gl = input$df_chisq_n)
         } else {
 
-          validate(need(chisq_problema_tab_cont() == "", "Não foi possível calcular sua solicitação. Verifique as entradas no painel lateral. Se o erro persistir, por favor, envie um e-mail para l-bioestatistica@hcpa.edu.br."))
+          validate(need(chisq_problema_tab_cont() == "", "Não foi possível calcular sua solicitação. Verifique as entradas no painel lateral. Se o erro persistir, por favor, envie um e-mail para psshealth@hcpa.edu.br."))
 
           matriz_prop <- as.matrix(tabela_chisq$tab)
 
@@ -459,7 +466,7 @@ mod_qui_quadrado_server <- function(id, tipo = "tamanho_amostral", txt_ajuda, tx
           ),
           div(style="display: inline-block;vertical-align:top; width: 80px;",
               numericInput(ns("chisq_by"), translation_pss("Intervalo", linguagem()), value = 0.1, min = 0, step = 0.1) %>%
-                .help_buttom(body = translation_pss("Essa sequência será utilizada para compor o eixo x do gráfico. A sequência irá do valor <b>Mínimo</b> até o valor <b>Máximo</b> em intervalos definidos no <b>Intervalo</b>.", linguagem()),
+                .help_buttom(linguagem = linguagem(), body = translation_pss("Essa sequência será utilizada para compor o eixo x do gráfico. A sequência irá do valor <b>Mínimo</b> até o valor <b>Máximo</b> em intervalos definidos no <b>Intervalo</b>.", linguagem()),
                              title = "Sequência")
           ),
           br(),
@@ -470,7 +477,7 @@ mod_qui_quadrado_server <- function(id, tipo = "tamanho_amostral", txt_ajuda, tx
                              label   = translation_pss("Digite valores de poder (%) para fazer o gráfico", linguagem()),
                              value   = "80, 90, 95",
                              width   = "400px") %>%
-                     .help_buttom(body = ajuda_cenarios_multiplos_valores())
+                     .help_buttom(linguagem = linguagem(), body = ajuda_cenarios_multiplos_valores())
             )
           ),
 
